#!/usr/bin/env groovy
import com.urbancode.anthill3.*
import com.urbancode.anthill3.plugin.scm.*
import java.text.*


final def dateParser = new DateParser();
final def ahpTool = new AHPTool();

//------------------------------------------------------------------------------
// PARSE PROPERTIES
//------------------------------------------------------------------------------

final def stepProps = ahpTool.getStepProperties()

final def workDir = new File('.').canonicalFile
final def out = System.out

// Repo
final String scmCmd     = stepProps['source/repo/commandPath']
final String baseUrl    = stepProps['source/repo/repoBaseUrl']
final String username   = stepProps['source/repo/username']
final String password   = stepProps['source/repo/password']
final boolean httpsNoVerify = Boolean.valueOf(stepProps['source/repo/httpsNoVerify']);
final String changelogUserField = stepProps['source/repo/changelogUserField'];

// Source
final String srcName       = stepProps['source'];
final File dir          = new File(workDir, stepProps['source/dirOffset']).canonicalFile // get checkout directory
final String remoteUrl  = stepProps['source/remoteUrl']
final String remoteName  = stepProps['source/remoteName']
final String branch     = stepProps['source/branch']
//final String sourceRevision = stepProps['source/revision']; should use revision from checkout step
final String userExcludesString = stepProps['source/excludeUsers'] ?: ''
final String fileFiltersString  = stepProps['source/fileFilters'] ?: '';

// Step
final def startRevision = stepProps['startRevision'] ?: ''
final def endRevision   = stepProps['endRevision'] ?: ''
final def startDate     = dateParser.parseDate(stepProps['startDate']) // explicit start date ?: startBuildLife.actualWorkspaceDate
final def endDate       = dateParser.parseDate(stepProps['endDate'])   // explicit end date ?: buildLife.actualWorkspaceDate

// Other
def parseLong = { value ->
   return (value && value != "") ? value.toLong() : null
}
final def startBuildLifeId = parseLong(stepProps['startBuildlifeId']) // change-log start status (if no explicit startDate)
if (!startRevision && startBuildLifeId) {
    startRevision = ahpTool.getBuildLifeProperties(startBuildLifeId)["workspace.revision.$srcName"]
}

if (!endRevision) {
    // We need to use HEAD because changelog --until=${revision} is exclusive and therefore we would not
    // get the most recent change
    endRevision = "HEAD"//ahpTool.getBuildLifeProperties()["workspace.revision.$srcName"]
}

//
// Execute
//
SCMChangelog step = new SCMChangelog();
step.directory  = dir;
step.scmCommand = scmCmd;
step.remoteBaseUrl  = baseUrl;
step.remoteUser = username;
step.remotePass = password;
step.httpsNoVerify  = httpsNoVerify;
step.changelogUserField = changelogUserField;
step.remoteUrl  = remoteUrl;
step.remoteName = remoteName;
step.branch     = branch;

step.startRevision = startRevision
//step.endRevision = endRevision // Use workspace revision as end point
step.startDate = startDate
//step.endDate = endDate // Use workspace revision as end point

step.changeSetFilter.setUserExcludes(userExcludesString);
step.changeSetFilter.setFileFilters(fileFiltersString);

def xml = step.execute()
if (xml) {
    ahpTool.addChangeSets(xml);
    println "";
}
