package com.urbancode.anthill3.plugin.scm

import com.urbancode.anthill3.*

import java.text.*;
import java.util.Date;

public class SCMCheckout extends SCMStep {

    //**************************************************************************
    // CLASS
    //**************************************************************************

    //**************************************************************************
    // INSTANCE
    //**************************************************************************

    Date date;

    /**
     *
     */
    public void execute() {

        TimeLog tl = new TimeLog();

        long initWStart = tl.now();
        initWorkspace();
        tl.log("SCMCheckout-> initWorkspace()-> ", initWStart);

        CommandHelper cmdHelper = getCommandHelperBase();

        // Convert date into revision
        if (!revision && date) {
            String dateString = getDateArgumentFormatter().format(date);
            revision = lookupRevision(date);
            println "Translated '$dateString' into $revision";
        }

        long switchOffBranch = tl.now();
        // switch off of branch to avoid `fatal: Cannot force update the current branch.`
        def coCmd = [scmCommand, '--no-pager', 'checkout', '--force', '--quiet', revision ?: remoteTrackingBranch]
        cmdHelper.runCommand('Git Checkout', coCmd)
        tl.log("SCMCheckout-> git checkout (switching off of branch)-> " + coCmd + "-> ", switchOffBranch);

        long createBranch = tl.now();
        // create branch from the specified start point
        def branchCommand = [scmCommand, '--no-pager', 'branch', '--force', branch]
        if (revision) {
            branchCommand << revision
        }
        else {
            branchCommand << '--track' << remoteTrackingBranch;
        }
        cmdHelper.runCommand('Git Branch', branchCommand)
        tl.log("SCMCheckout-> git branch (create branch from specific start point)-> " + branchCommand + "-> ", createBranch);

        long checkout = tl.now();
        def checkoutCommand = [scmCommand, '--no-pager', 'checkout', '--force', branch]
        cmdHelper.runCommand('Git Checkout', checkoutCommand)
        tl.log("SCMCheckout-> git checkout-> " + checkoutCommand + "-> ", checkout);

        long translate = tl.now();
        // translate symbolic revisions into sha1
        if (!revision || !(revision ==~ /[0-9a-fA-F]{40}/)) {
            println "Get revision id for workspace"
            def revisionCommand = [scmCommand, '--no-pager', 'rev-parse', '--verify', 'HEAD'];
            revision = getCommandText(revisionCommand);
            println("Using revision $revision");
        }
        tl.log("SCMCheckout-> translate revisions to sha1-> ", translate);

        tl.log("SCMCheckout-> execute()-> ", initWStart);
        tl.log("*** ===== END ENTRY ===== ***", tl.now()); // indicate the end of log entry
    }
}
