package com.urbancode.anthill3.plugin.scm

import com.urbancode.anthill3.*

import java.io.File;
import java.util.Date;
import java.util.regex.Pattern
import java.util.regex.Matcher

public class SCMReview extends SCMStep {

    //**************************************************************************
    // CLASS
    //**************************************************************************

    //**************************************************************************
    // INSTANCE
    //**************************************************************************

    String message;
    String labels;
    Integer review;
    boolean submit = false;

    /**
     *
     */
    public void execute() {
        String url = calculateRepositoryUrl();

        Matcher m = Pattern.compile('ssh://(?:([^@]+)@)?([^/:]+)(?::(\\d+))?/.*').matcher(url);
        if (!url.startsWith("ssh://") || !m.matches()) {
            throw new Exception("Gerrit commands must be run over ssh. Could not parse relevant info from $url");
        }
        String user = m.group(1);
        String host = m.group(2);
        String port = m.group(3);

        String hostWithUser = host;
        if (user) {
            hostWithUser = user + "@" + host;
        }

        final def cmdHelper = getCommandHelperBase();

        def reviewCmd = ['ssh'];
        if (port) {
            reviewCmd << '-p' << port
        }
        reviewCmd << hostWithUser << 'gerrit' << 'review'
        if (message) {
            reviewCmd << '--message'
            reviewCmd << "'$message'" // extra quotes because shell evaluation of argument boundaries over ssh
        }
        if (labels) {
            labels.split(',').each{ label ->
                label = label.trim();
                if (label) {
                    reviewCmd << '--label' << label
                }
            }
        }
        if (review != null) {
            reviewCmd << '--code-review' << review
        }
        if (submit) {
            reviewCmd << '--submit'
        }
        reviewCmd << revision

        cmdHelper.runCommand('Run Gerrit Review Command', reviewCmd);
    }
}
