package com.urbancode.anthill3.plugin.scm;

import java.text.DecimalFormatSymbols;

public class TimeLog {

    private static final String timeGitOutputFile = System.getenv("TIME_GIT_OUTPUT_FILE"); // on unix use "/dev/null" to only print to std out

    public TimeLog() {}

    public String log(String message, long startTimeNano) {
        if (timeGitOutputFile) {
            try {
                File outFile = new File(timeGitOutputFile);
                outFile = outFile.getCanonicalFile();
                File parentFile = outFile.getParentFile();
                if (parentFile) {
                    parentFile.mkdirs();
                }
                outFile.createNewFile();
                Writer writer = new FileWriter(outFile, true);
                try {
                    long currentNano = System.nanoTime();
                    long nanos = currentNano - startTimeNano;
                    long millis = nanos / 1000000L;
                    Formatter formatter = new Formatter(Locale.US);
                    try {
                        char decimal = '.';
                        Locale locale = formatter.locale();
                        if (locale != null) {
                            DecimalFormatSymbols symbols = new DecimalFormatSymbols(locale);
                            decimal = symbols.getDecimalSeparator();
                        }
                        Long sec = millis / 1000L;
                        Long frac = millis % 1000L;
                        formatter.format("[TIME LOG] %s %s %,d%c%03d seconds",
                                new Date(),
                                message,
                                sec,
                                decimal,
                                frac);
                        String line = formatter.toString();
                        writer.println(line);
                        println(line);
                    }
                    finally {
                        formatter.close();
                    }
                }
                finally {
                    writer.close();
                }
            }
            catch (IOException ioExc) {
                ioExc.printStackTrace();
            }
            catch (SecurityException secExc) {
                secExc.printStackTrace();
            }
        }
    }

    public long now() {
        return System.nanoTime();
    }

}
